OC.L10N.register(
    "core",
    {
    "Please select a file." : "Vyberte soubor.",
    "File is too big" : "Soubor je příliš velký",
    "The selected file is not an image." : "Vybraný soubor není obrázek.",
    "The selected file cannot be read." : "Vybraný soubor se nedaří přečíst.",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahraný soubor překračuje nastavení MAX_FILE_SIZE, které bylo zadáno v HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří zapsat na úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
    "Invalid file provided" : "Poskytnut neplatný soubor",
    "No image or file provided" : "Neposkytnut žádný obrázek nebo soubor",
    "Unknown filetype" : "Neznámý typ souboru",
    "An error occurred. Please contact your admin." : "Došlo k chybě. Obraťte se na svého správce.",
    "Invalid image" : "Neplatný obrázek",
    "No temporary profile picture available, try again" : "Není k dispozici žádný dočasný profilový obrázek – zkuste to znovu",
    "No crop data provided" : "Nezadáno, jak má být obrázek oříznut",
    "No valid crop data provided" : "Neposkytnuta platná data pro oříznutí obrázku",
    "Crop is not square" : "Ořez není čtvercový",
    "State token does not match" : "Stavový token se neshoduje",
    "Invalid app password" : "Neplatné heslo pro aplikaci",
    "Could not complete login" : "Přihlášení se nedaří dokončit",
    "State token missing" : "Chybí stavový token",
    "Your login token is invalid or has expired" : "Váš přihlašovací token není platný nebo jeho platnost skončila",
    "Please use original client" : "Prosím použijte původního klienta",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitní vydání Nextcloud není podporováno a push oznámení jsou proto omezená.",
    "Login" : "Přihlásit",
    "Unsupported email length (>255)" : "Nepodporovaná délka e-mailu (>255)",
    "Password reset is disabled" : "Resetování hesla je vypnuté",
    "Could not reset password because the token is expired" : "Heslo není možné resetovat, protože platnost tokenu skončila",
    "Could not reset password because the token is invalid" : "Heslo není možné resetovat, protože token není platný",
    "Password is too long. Maximum allowed length is 469 characters." : "Heslo je příliš dlouhé. Délka může být nejvýše 469 znaků.",
    "%s password reset" : "Reset hesla uživatele %s",
    "Password reset" : "Reset hesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na tlačítko níže. Pokud jste o resetování hesla nežádali, tento e-mail ignorujte.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na následující odkaz. Pokud jste o reset nežádali, tento e-mail ignorujte.",
    "Reset your password" : "Resetovat vaše heslo",
    "The given provider is not available" : "Daný poskytovatel není k dispozici",
    "Task not found" : "Úkol nenalezen",
    "Internal error" : "Vnitřní chyba",
    "Not found" : "Nenalezeno",
    "Node is locked" : "Uzel je uzamčen",
    "Bad request" : "Chybný požadavek",
    "Requested task type does not exist" : "Požadovaný typ úkolu neexistuje",
    "Necessary language model provider is not available" : "Nezbytný poskytovatel jazykového modelu není k dsipozici",
    "No text to image provider is available" : "Není k dispozici žádný poskytovatel převodu textu na obrázek",
    "Image not found" : "Obrázek nenalezen",
    "No translation provider available" : "Není k dispozici žádný poskytovatel překladu",
    "Could not detect language" : "Nepodařilo se zjistit jazyk",
    "Unable to translate" : "Nedaří se přeložit",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Krok opravy:",
    "Repair info:" : "Informace o opravě:",
    "Repair warning:" : "Varování ohledně opravy:",
    "Repair error:" : "Chyba opravy:",
    "Nextcloud Server" : "Server Nextcloud",
    "Some of your link shares have been removed" : "Některá vaše sdílení odkazem byla odstraněna",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvůli chybě v zabezpečení bylo třeba odstranit některé z sdílení odkazem. Další informace viz odkaz.",
    "The account limit of this instance is reached." : "Bylo dosaženo limitu počtu účtů této instance.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Aby bylo možné zvýšit limit počtu uživatelských účtů, zadejte v aplikaci podpora svůj klíč k předplatnému. Toto také zpřístupní veškeré další výhody, které nabízí Nextcloud pro podniky a je velmi doporučeno pro provozování ve firmách.",
    "Learn more ↗" : "Zjistit víc ↗",
    "Preparing update" : "Příprava pro aktualizaci",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Zaktualizujte z příkazového řádku, protože aktualizování z webového prohlížeče je vypnuté ve vašem config.php.",
    "Turned on maintenance mode" : "Přepnuto do režimu údržby",
    "Turned off maintenance mode" : "Přepnuto zpět z režimu údržby",
    "Maintenance mode is kept active" : "Režim údržby je ponechán",
    "Updating database schema" : "Aktualizace schéma databáze",
    "Updated database" : "Zaktualizována databáze",
    "Update app \"%s\" from App Store" : "Aktualizovat aplikaci „%s“ z katalogu aplikací",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Probíhá zjišťování, zda je možné aktualizovat schéma databáze používané pro %s (v závislosti na velikosti databáze to může zabrat delší dobu)",
    "Updated \"%1$s\" to %2$s" : "Aktualizováno „%1$s“ na %2$s",
    "Set log level to debug" : "Nastavit úroveň podrobnosti záznamu událostí na stupeň ladění (debug)",
    "Reset log level" : "Vrátit podrobnost záznamu událostí na výchozí úroveň",
    "Starting code integrity check" : "Spouští se kontrola neporušenosti kódu",
    "Finished code integrity check" : "Kontrola neporušenosti zdrojových kódů aplikace dokončena",
    "%s (incompatible)" : "%s (nekompatibilní)",
    "The following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
    "Already up to date" : "Už je aktuální",
    "Windows Command Script" : "Windows cmd skript",
    "Electronic book document" : "Dokument – elektronická knížka",
    "TrueType Font Collection" : "Sada TrueType písem",
    "Web Open Font Format" : "Písmo ve formátu Web Open",
    "GPX geographic data" : "Geografická data GPX",
    "Gzip archive" : "Gzip archiv",
    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
    "Java source code" : "Zdrojový kód v Javě",
    "JavaScript source code" : "Zdrojový kód v JavaScriptu",
    "JSON document" : "JSON dokument",
    "Microsoft Access database" : "Databáze Microsoft Access",
    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
    "Microsoft Word document" : "Dokument Microsoft Word",
    "Unknown" : "Neznámé",
    "PDF document" : "PDF dokument",
    "PostScript document" : "PostScript dokument",
    "RSS summary" : "RSS shrnutí",
    "Android package" : "Balíček pro Android",
    "KML geographic data" : "Geografická data KML",
    "KML geographic compressed data" : "Komprimovaná KLM geografická data",
    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
    "Excel spreadsheet" : "Sešit Excel",
    "Excel add-in" : "Doplněk do Excel",
    "Excel 2007 binary spreadsheet" : "Sešit Excel 2007 (v binárním formátu)",
    "Excel spreadsheet template" : "Šablona sešitu Excel",
    "Outlook Message" : "Outlook zpráva",
    "PowerPoint presentation" : "PowerPoint prezentace",
    "PowerPoint add-in" : "Doplněk do PowerPoint",
    "PowerPoint presentation template" : "Šablona prezentace PowerPoint",
    "Word document" : "Dokument Word",
    "ODF formula" : "ODF vzorec",
    "ODG drawing" : "ODG kresba",
    "ODG drawing (Flat XML)" : "Kresba ve formátu ODG (ploché XML)",
    "ODG template" : "ODG šablona",
    "ODP presentation" : "ODP prezentace",
    "ODP presentation (Flat XML)" : "Prezentace ve formátu ODP (ploché XML)",
    "ODP template" : "ODP šablona",
    "ODS spreadsheet" : "ODS šablona",
    "ODS spreadsheet (Flat XML)" : "Sešit ve formátu ODS (ploché XML)",
    "ODS template" : "ODS šablona",
    "ODT document" : "ODT dokument",
    "ODT document (Flat XML)" : "Dokument ve formátu ODT (ploché XML)",
    "ODT template" : "ODT šablona",
    "PowerPoint 2007 presentation" : "Prezentace PowerPoint 2007",
    "PowerPoint 2007 show" : "Show PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Šablona prezentace PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Sešit Excel 2007",
    "Excel 2007 spreadsheet template" : "Šablona sešitu Excel 2007",
    "Word 2007 document" : "Dokument Word 2007",
    "Word 2007 document template" : "Šablona dokumentu Word 2007",
    "Microsoft Visio document" : "Dokument Microsoft Visio",
    "WordPerfect document" : "WordPerfect dolument",
    "7-zip archive" : "7-zip archiv",
    "Blender scene" : "Scéna v Blenderu",
    "Bzip2 archive" : "Bzip2 archiv",
    "Debian package" : "Debian balíček",
    "FictionBook document" : "FictionBook dokument",
    "Unknown font" : "Neznámé písmo",
    "Krita document" : "Krita dokument",
    "Mobipocket e-book" : "Mobipocket e-kniha",
    "Windows Installer package" : "Balíček Windows instalátoru",
    "Perl script" : "Perl skript",
    "PHP script" : "PHP skript",
    "Tar archive" : "Tar archiv",
    "XML document" : "XML dokument",
    "YAML document" : "YAML dokument",
    "Zip archive" : "Zip archiv",
    "Zstandard archive" : "Zstandard archiv",
    "AAC audio" : "AAC audio",
    "FLAC audio" : "FLAC audio",
    "MPEG-4 audio" : "MPEG-4 audio",
    "MP3 audio" : "MP3 audio",
    "Ogg audio" : "Ogg audio",
    "RIFF/WAVe standard Audio" : "Audio ve standardu RIFF/WAVe",
    "WebM audio" : "WebM audio",
    "MP3 ShoutCast playlist" : "Seznam stop MP3 ShoutCast",
    "Windows BMP image" : "Windows BMP obrázek",
    "Better Portable Graphics image" : "Obrázek ve formátu Beter Portable Graphics",
    "EMF image" : "EMF obrázek",
    "GIF image" : "GIF obrázek",
    "HEIC image" : "HEIC obrázek",
    "HEIF image" : "HEIF obrázek",
    "JPEG-2000 JP2 image" : "Obrázek JPEG-2000 JP2",
    "JPEG image" : "JPEG obrázek",
    "PNG image" : "Obrázek PNG",
    "SVG image" : "SVG obrázek",
    "Truevision Targa image" : "Obrázek Truevision Targa",
    "TIFF image" : "TIFF obrázek",
    "WebP image" : "WebP obrázek",
    "Digital raw image" : "Obrázek – digitální negativ",
    "Windows Icon" : "Windows ikona",
    "Email message" : "E-mailová zpráva",
    "VCS/ICS calendar" : "VCS/ICS kalednář",
    "CSS stylesheet" : "CSS kaskádové styly",
    "CSV document" : "CSV dokument",
    "HTML document" : "HTML dokument",
    "Markdown document" : "Markdown dokument",
    "Org-mode file" : "soubor Org-mode",
    "Plain text document" : "Dokument neformátovaného textu",
    "Rich Text document" : "Dokument typu Rich Text",
    "Electronic business card" : "Elektronická vizitka",
    "C++ source code" : "Zdrojový kód v C++",
    "LDIF address book" : "LDIF adresář kontaktů",
    "NFO document" : "NFO dokument",
    "PHP source" : "PHP zdrojové kódy",
    "Python script" : "Python skript",
    "ReStructuredText document" : "ReStructuredText dokument",
    "3GPP multimedia file" : "3GPP soubor multimédií",
    "MPEG video" : "MPEG video",
    "DV video" : "DV video",
    "MPEG-2 transport stream" : "MPEG-2 transportní proud",
    "MPEG-4 video" : "MPEG-4 video",
    "Ogg video" : "Ogg video",
    "QuickTime video" : "QuickTime video",
    "WebM video" : "WebM video",
    "Flash video" : "Flash video",
    "Matroska video" : "Matroska video",
    "Windows Media video" : "Windows Media video",
    "AVI video" : "AVI video",
    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
    "unknown text" : "neznámý text",
    "Hello world!" : "Dobrý den světe!",
    "sunny" : "slunečno",
    "Hello {name}, the weather is {weather}" : "Dobrý den {name}, počasí je {weather}",
    "Hello {name}" : "Dobrý den {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
    "new" : "nový",
    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace – opuštění této stránky může v některých prostředích proces přerušit.",
    "Update to {version}" : "Aktualizovat na {version}",
    "An error occurred." : "Došlo k chybě.",
    "Please reload the page." : "Načtěte stránku znovu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizace nebyla úspěšná. Další informace <a href=\"{url}\">se dočtete v příspěvku na diskuzním fóru</a>, pojednávajícím o tomto problému.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizace nebyla úspěšná. Prosím nahlaste tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitě projektu Nextcloud</a>",
    "Continue to {productName}" : "Pokračujte k {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizace proběhla úspěšně. Za %n sekundu budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekund budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}"],
    "Applications menu" : "Nabídka aplikací",
    "Apps" : "Aplikace",
    "More apps" : "Více aplikací",
    "_{count} notification_::_{count} notifications_" : ["{count} upozornění","{count} upozornění","{count} upozornění","{count} upozornění"],
    "No" : "Ne",
    "Yes" : "Ano",
    "The remote URL must include the user." : "Je třeba, aby vzdálená URL obsahovala uživatele.",
    "Invalid remote URL." : "Neplatná vzdálená URL.",
    "Failed to add the public link to your Nextcloud" : "Nepodařilo se přidání veřejného odkazu do Nextcloud",
    "Federated user" : "Federovaný uživatel",
    "user@your-nextcloud.org" : "uzivatel@vas-nextcloud.org",
    "Create share" : "Vytvořit sdílení",
    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
    "Please copy the link manually:" : "Zkopírujte odkaz ručně:",
    "Custom date range" : "Uživatelsky určené datumové rozmezí",
    "Pick start date" : "Vybrat datum začátku",
    "Pick end date" : "Vybrat datum konce",
    "Search in date range" : "Hledat v období",
    "Search in current app" : "Hledat ve stávající aplikaci",
    "Clear search" : "Vyčistit hledání",
    "Search everywhere" : "Hledat všude",
    "Searching …" : "Hledání…",
    "Start typing to search" : "Hledejte psaním",
    "No matching results" : "Žádné odpovídající výsledky",
    "Today" : "Dnes",
    "Last 7 days" : "Uplynulých 7 dnů",
    "Last 30 days" : "Uplynulých 30 dnů",
    "This year" : "Tento rok",
    "Last year" : "Uplynulý rok",
    "Unified search" : "Sjednocené vyhledávání",
    "Search apps, files, tags, messages" : "Prohledat aplikace, soubory, štítky a zprávy",
    "Places" : "Místa",
    "Date" : "Datum",
    "Search people" : "Hledat osoby",
    "People" : "Lidé",
    "Filter in current view" : "Filtrovat ve stávajícím pohledu",
    "Results" : "Výsledky",
    "Load more results" : "Načíst další výsledky",
    "Search in" : "Hledat v",
    "Log in" : "Přihlásit",
    "Logging in …" : "Přihlašování…",
    "Log in to {productName}" : "Přihlásit se do {productName}",
    "Wrong login or password." : "Nesprávné přihlašovací jméno nebo heslo",
    "This account is disabled" : "Účet je znepřístupněn",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bylo rozpoznáno několik neplatných pokusů o přihlášeni z vaší IP adresy. Další přihlášení bude možné za 30 sekund.",
    "Account name or email" : "Název účtu nebo e-mail",
    "Account name" : "Název účtu",
    "Server side authentication failed!" : "Ověření se na straně serveru se nezdařilo!",
    "Please contact your administrator." : "Obraťte se na svého správce.",
    "Session error" : "Chyba relace",
    "It appears your session token has expired, please refresh the page and try again." : "Zdá se, že platnost vašeho tokenu relace skončila – načtěte stránku znovu a zkuste znovu, o co jste se pokoušeli.",
    "An internal error occurred." : "Došlo k vnitřní chybě.",
    "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na správce.",
    "Password" : "Heslo",
    "Log in with a device" : "Přihlásit se pomocí zařízení",
    "Login or email" : "Přihlašovací jméno nebo e-mail",
    "Your account is not setup for passwordless login." : "Váš účet nemá nastavené přihlašování se bez hesla.",
    "Your connection is not secure" : "Vaše připojení není zabezpečené",
    "Passwordless authentication is only available over a secure connection." : "Ověření se bez hesla je k dispozici pouze přes zabezpečené připojení.",
    "Browser not supported" : "Prohlížeč není podporován",
    "Passwordless authentication is not supported in your browser." : "Přihlašování se bez hesla není ve vámi používaném prohlížeči podporováno.",
    "Reset password" : "Resetovat heslo",
    "Back to login" : "Zpět na přihlášení",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Pokud tento účet existuje, byla na jeho e-mailovou adresu odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, zkontrolujte správnost zadání e-mailové adresy a/nebo přihlašovacího jména, dále se podívejte také do složek s nevyžádanou poštou (spam). Případně požádejte svého místního správce o pomoc.",
    "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat e-mail pro změnu hesla. Obraťte se na správce.",
    "Password cannot be changed. Please contact your administrator." : "Heslo nelze změnit. Obraťte se na svého správce systému.",
    "New password" : "Nové heslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše soubory jsou šifrované. Vyresetováním hesla nebude způsob, jak získat vaše data zpět. Pokud nevíte, co dělat, nepokračujte a obraťte se na svého správce. Opravdu chcete pokračovat?",
    "I know what I'm doing" : "Vím co dělám",
    "Resetting password" : "Resetuje se heslo",
    "Schedule work & meetings, synced with all your devices." : "Plánujte si práci a schůzky – synchronizováno napříč všemi vašimi zařízeními.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Uchovávejte si údaje svých kolegů a přátel na jednom místě, aniž by k jejim osobním údajům získal přístup někdo jiný.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchý e-mailový klient, propojený s aplikacemi Soubory, Kontakty a Kalendář.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
    "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
    "Recommended apps" : "Doporučené aplikace",
    "Loading apps …" : "Načítání aplikací…",
    "Could not fetch list of apps from the App Store." : "Nedaří se získat seznam aplikací z katalogu.",
    "App download or installation failed" : "Stažení aplikace nebo její instalace se nezdařilo",
    "Cannot install this app because it is not compatible" : "Tuto aplikaci nelze nainstalovat, protože není kompatibilní",
    "Cannot install this app" : "Tuto aplikaci nelze nainstalovat",
    "Skip" : "Přeskočit",
    "Installing apps …" : "Instalace aplikací…",
    "Install recommended apps" : "Nainstalovat doporučené aplikace",
    "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
    "Settings menu" : "Nabídka nastavení",
    "Loading your contacts …" : "Načítání vašich kontaktů…",
    "Looking for {term} …" : "Hledání {term}…",
    "Search contacts" : "Hledat v kontaktech",
    "Reset search" : "Resetovat hledání",
    "Search contacts …" : "Hledat v kontaktech…",
    "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
    "No contacts found" : "Nenalezeny žádné kontakty",
    "Show all contacts" : "Zobrazit všechny kontakty",
    "Install the Contacts app" : "Nainstalovat aplikaci Kontakty",
    "Search" : "Hledat",
    "No results for {query}" : "Pro {query} nic nenalezeno",
    "Press Enter to start searching" : "Vyhledávání zahájíte stisknutím klávesy Enter",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znak","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaků","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky"],
    "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
    "Search for {name} only" : "Hledat pouze {name}",
    "Loading more results …" : "Načítání dalších výsledků…",
    "Forgot password?" : "Zapomněli jste heslo?",
    "Back to login form" : "Zpět na formulář pro přihlášení",
    "Back" : "Zpět",
    "Login form is disabled." : "Formulář pro přihlášení je vypnut",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
    "More actions" : "Další akce",
    "User menu" : "Nabídka uživatele",
    "You will be identified as {user} by the account owner." : "Vlastníkem účtu budete identifikováni jako {user}.",
    "You are currently not identified." : "V tuto chvíli nejste identifikováni.",
    "Set public name" : "Nastavit veřejné jméno",
    "Change public name" : "Změnit veřejné jméno",
    "Password is too weak" : "Heslo je příliš snadno prolomitelné",
    "Password is weak" : "Heslo je snadno prolomitelné",
    "Password is average" : "Heslo je postačující",
    "Password is strong" : "Heslo je odolné",
    "Password is very strong" : "Heslo je velmi odolné",
    "Password is extremely strong" : "Heslo je extrémně odolné",
    "Unknown password strength" : "Neznámá odolnost hesla",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor <code>.htaccess</code> nefunguje.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informace o tom, jak správně nastavit váš server, naleznete v {linkStart}dokumentaci{linkEnd}",
    "Autoconfig file detected" : "Zjištěn soubor s automatického nastavení",
    "The setup form below is pre-filled with the values from the config file." : "Níže uvedený formulář nastavení je předvyplněný hodnotami ze souboru s nastaveními.",
    "Security warning" : "Varování ohledně zabezpečení",
    "Create administration account" : "Vytvořit účet pro správnu",
    "Administration account name" : "Název účtu pro správu",
    "Administration account password" : "Heslo k účtu pro správu",
    "Storage & database" : "Úložiště a databáze",
    "Data folder" : "Složka s daty",
    "Database configuration" : "Nastavení databáze",
    "Only {firstAndOnlyDatabase} is available." : "K dispozici je pouze {firstAndOnlyDatabase}.",
    "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
    "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
    "Performance warning" : "Varování ohledně výkonu",
    "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
    "Database user" : "Uživatel databáze",
    "Database password" : "Heslo do databáze",
    "Database name" : "Název databáze",
    "Database tablespace" : "Tabulkový prostor databáze",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
    "Database host" : "Stroj na kterém se nachází databáze",
    "localhost" : "localhost",
    "Installing …" : "Instalace…",
    "Install" : "Nainstalovat",
    "Need help?" : "Potřebujete nápovědu?",
    "See the documentation" : "Viz dokumentace",
    "{name} version {version} and above" : "{name} verze {version} a novější",
    "This browser is not supported" : "Tento prohlížeč není podporován",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
    "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
    "Supported versions" : "Podporované verze",
    "Search {types} …" : "Hledat {types}…",
    "Choose {file}" : "Zvolit {file}",
    "Choose" : "Vybrat",
    "Copy to {target}" : "Zkopírovat do {target}",
    "Copy" : "Zkopírovat",
    "Move to {target}" : "Přesunout do {target}",
    "Move" : "Přesunout",
    "OK" : "OK",
    "read-only" : "pouze pro čtení",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} souborový konflikt","{count} souborové konflikty","{count} souborových konfliktů","{count} souborové konflikty"],
    "One file conflict" : "Jeden konflikt souboru",
    "New Files" : "Nové soubory",
    "Already existing files" : "Už existující soubory",
    "Which files do you want to keep?" : "Které soubory chcete ponechat?",
    "If you select both versions, the copied file will have a number added to its name." : "Pokud zvolíte obě verze, zkopírovaný soubor bude mít název doplněn o číslo.",
    "Cancel" : "Storno",
    "Continue" : "Pokračovat",
    "(all selected)" : "(vše vybrané)",
    "({count} selected)" : "(vybráno {count})",
    "Error loading file exists template" : "Chyba při načítání šablony existence souboru",
    "Saving …" : "Ukládání…",
    "seconds ago" : "před několika sekundami",
    "Connection to server lost" : "Připojení k serveru ztraceno",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
    "Add to a project" : "Přidat do projektu",
    "Show details" : "Zobrazit podrobnosti",
    "Hide details" : "Skrýt podrobnosti",
    "Rename project" : "Přejmenovat projekt",
    "Failed to rename the project" : "Přejmenování projektu se nezdařilo",
    "Failed to create a project" : "Vytvoření projektu se nezdařilo",
    "Failed to add the item to the project" : "Přidání položky do projektu se nezdařilo",
    "Connect items to a project to make them easier to find" : "Připojte položky k projektu aby je bylo snazší nalézt",
    "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
    "New in" : "Nové v",
    "View changelog" : "Zobrazit souhrn změn",
    "No action available" : "Není dostupná žádná akce",
    "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
    "Close \"{dialogTitle}\" dialog" : "Zavřít „{dialogTitle}“ dialog",
    "Email length is at max (255)" : "Délka e-mailu je na maximu (255)",
    "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
    "Restricted" : "Omezeno",
    "Invisible" : "Není vidět",
    "Delete" : "Smazat",
    "Rename" : "Přejmenovat",
    "Collaborative tags" : "Štítky pro spolupráci",
    "No tags found" : "Nenalezeny žádné štítky",
    "Clipboard not available, please copy manually" : "Schránka není k dispozici – zkopírujte ručně",
    "Personal" : "Osobní",
    "Accounts" : "Účty",
    "Admin" : "Správa",
    "Help" : "Nápověda",
    "Access forbidden" : "Přístup zakázán",
    "You are not allowed to access this page." : "Nemáte oprávnění k přístupu k této stránce.",
    "Back to %s" : "Zpět na %s",
    "Page not found" : "Stránka nenalezena",
    "The page could not be found on the server or you may not be allowed to view it." : "Stránku se na serveru nepodařilo nalézt nebo nemáte oprávnění ji zobrazit.",
    "Too many requests" : "Příliš mnoho požadavků",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
    "Error" : "Chyba",
    "Internal Server Error" : "Vnitřní chyba serveru",
    "The server was unable to complete your request." : "Server nemohl dokončit váš požadavek.",
    "If this happens again, please send the technical details below to the server administrator." : "Pokud se toto stane znovu, pošlete níže uvedené technické podrobnosti správci serveru.",
    "More details can be found in the server log." : "Další podrobnosti naleznete v záznamu událostí serveru.",
    "For more details see the documentation ↗." : "Podrobnosti naleznete v dokumentaci ↗.",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Federovaná adresa: %s",
    "Request ID: %s" : "Identifikátor požadavku: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Zpráva: %s",
    "File: %s" : "Soubor: %s",
    "Line: %s" : "Řádek: %s",
    "Trace" : "Trace",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Zdá se, že se pokoušíte přeinstalovat svou instanci NextCloud. Nicméně ve vašem adresáři s nastaveními chybí soubor CAN_INSTALL. Aby bylo možné pokračovat, takový tam vytvořte.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nedaří se ze složky s nastaveními odstranit soubor CAN_INSTALL. Odstraňte ho proto ručně.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tato aplikace potřebuje pro správnou funkčnost JavaScript. {linkstart}Povolte ho{linkend} a stránku znovu načtěte.",
    "Skip to main content" : "Přeskočit a přejít k hlavnímu obsahu",
    "Skip to navigation of app" : "Přeskočit na navigaci aplikace",
    "Go to %s" : "Jít na %s",
    "Get your own free account" : "Získejte svůj vlastní účet zdarma",
    "Connect to your account" : "Propojit s vaším účtem",
    "Please log in before granting %1$s access to your %2$s account." : "Přihlaste se abyste mohli %1$s udělit přístup k vašemu %2$s účtu.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Pokud se nepokoušíte nastavit nové zařízení či aplikaci, někdo se pokouší vás ošálit a získat tak přístup k vašim datům. V takovém případě nepokračujte a obraťte se na svého správce systémů.",
    "App password" : "Heslo pro aplikaci",
    "Grant access" : "Udělit přístup",
    "Alternative log in using app password" : "Alternativní přihlášení pomocí hesla pro aplikaci",
    "Account access" : "Přístup k účtu",
    "Currently logged in as %1$s (%2$s)." : "Nyní jste přihlášeni jako %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu.",
    "Account connected" : "Účet připojen",
    "Your client should now be connected!" : "Váš klient by nyní měl být připojen!",
    "You can close this window." : "Toto okno je možné zavřít.",
    "Previous" : "Předchozí",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong or expired. Please try again or request a new one." : "Nesprávné heslo nebo jeho platnost skončila. Prosím zkuste to znovu nebo si zažádejte o nové.",
    "Please type in your email address to request a temporary password" : "Pokud si chcete požádat o dočasné heslo, zadejte svou e-mailovou adresu",
    "Email address" : "E-mailová adresa",
    "Password sent!" : "Heslo zasláno!",
    "You are not authorized to request a password for this share" : "Nejste oprávněni vyžádat si heslo pro toto sdílení",
    "Two-factor authentication" : "Dvoufaktorové přihlášení",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Zvolte druhý faktor pro ověřování:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedaří se načíst ani jednu ze zapnutých metod dvouúrovňového ověřování. Obraťte se na svého správce.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Obraťte o pomoc na svého správce.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Pokračujte nastavením dvoufázového ověřování.",
    "Set up two-factor authentication" : "Nastavit dvoufázové ověřování",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Přihlaste se použitím nějakého ze svých záložních kódů nebo se obraťte o pomoc na svého správce.",
    "Use backup code" : "Použít záložní kód",
    "Cancel login" : "Zrušit přihlášení",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Vylepšené zabezpečení je vynuceno vaším účtem. Zvolte, kterého poskytovatele nastavit:",
    "Error while validating your second factor" : "Chyba při ověřování druhého faktoru",
    "Access through untrusted domain" : "Přístup prostřednictvím nedůvěryhodné domény",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Obraťte se na svého správce. Pokud jste jím vy, upravte v souboru s nastaveními config/config.php parametr „trusted_domains“ podle příkladu v config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Další informace o tom, jak toto nastavit jsou k dispozici v %1$sdokumentaci%2$s.",
    "App update required" : "Vyžadována aktualizace aplikace",
    "%1$s will be updated to version %2$s" : "%1$s bude aktualizováno na verzi %2$s",
    "The following apps will be updated:" : "Následující aplikace budou aktualizovány:",
    "These incompatible apps will be disabled:" : "Tyto nekompatibilní aplikace budou vypnuty:",
    "The theme %s has been disabled." : "Motiv vzhledu %s byl vypnut.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Před provedením dalšího kroku se ujistěte, že je zazálohována databáze a složky s nastaveními a daty.",
    "Start update" : "Spustit aktualizaci",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Abyste zabránili překračování časových limitů u větších instalací, můžete místo toho v adresáři s nainstalovanou aplikací spustit:",
    "Detailed logs" : "Podrobné záznamy událostí",
    "Update needed" : "Je třeba provést aktualizaci",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použijte aktualizační příkazový řádek, protože máte velkou instanci s více než 50 účty.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro pomoc, nahlédněte do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentace</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Beru na vědomí, že při aktualizaci skrze webové rozhraní hrozí nebezpečí překročení časového limitu požadavku, který může vyústit ve ztrátu dat. Mám pro takový případ zálohu a vím, jak ji v případě nezdaru obnovit.",
    "Upgrade via web on my own risk" : "Na vlastní nebezpečí aktualizovat skrze web",
    "Maintenance mode" : "Režim údržby",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
    "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
    "You have not added any info yet" : "Zatím jste nezadali žádné informace",
    "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
    "Error opening the user status modal, try hard refreshing the page" : "Chyba při otevírání dialogu stavu uživatele, pokus o opětovné načtení stránky",
    "Edit Profile" : "Upravit profil",
    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
    "Very weak password" : "Velmi snadno prolomitelné heslo",
    "Weak password" : "Snadno prolomitelné heslo",
    "So-so password" : "Ještě použitelné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Odolné heslo",
    "Profile not found" : "Profil nenalezen",
    "The profile does not exist." : "Profil neexistuje.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
    "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
    "New admin account name" : "Název účtu nového správce",
    "New admin password" : "Heslo nového správce",
    "Show password" : "Zobrazit heslo",
    "Toggle password visibility" : "Přepnout viditelnost hesla",
    "Configure the database" : "Nastavit databázi",
    "Only %s is available." : "Je k dispozici pouze %s.",
    "Database account" : "Účet do databáze"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
